@@ -11,7 +11,7 @@ from Crypto.Protocol.KDF import PBKDF2
 from cryptography.fernet import Fernet
 from random import randbytes, shuffle
 from platform import system as get_platform
-from file_encryption import AES_encrypt_file, AES_decrypt_file, BLO_encrypt_file, BLO_decrypt_file 
+from .file_encryption import AES_encrypt_file, AES_decrypt_file, BLO_encrypt_file, BLO_decrypt_file 
 
 class NoKeyError(Exception):
     """
